==> id-broker-plugin_1.6.14.tar.gz: id-broker-plugin-1.6.14/tests/host/98_ucsschool-id-broker-performance/36_selfd_teacher_flow.py <==
#!/usr/share/ucs-test/runner /usr/bin/pytest-3 -l -v
## -*- coding: utf-8 -*-
## desc: check performance of teacher flow (get token - get metadata - get groups - get users of groups)
## tags: [ucsschool-id-broker, self-disclosure-api, performance]
## exposure: safe
## packages: []
## bugs: [54547]

import os

import pytest

LOCUST_PARALLEL = os.environ.get("LOCUST_PARALLEL", None)

BASE_DIR = "/var/lib/id-broker-performance-tests"
RESULT_DIR = os.path.join(BASE_DIR, "results")
LOCUST_FILES_DIR = os.path.join(BASE_DIR, "performance_tests", "self_disclosure")

LOCUST_FILE = "teacher_flow.py"
LOCUST_FILE_PATH = os.path.join(LOCUST_FILES_DIR, LOCUST_FILE)
if LOCUST_PARALLEL:
    RESULT_FILE_BASE_PATH = os.path.join(RESULT_DIR, "parallel_self-disclosure_teacher_flow")
else:
    RESULT_FILE_BASE_PATH = os.path.join(RESULT_DIR, "self-disclosure_teacher_flow")
HOST = "self-disclosure"
URL_NAMES = [
    "login?kc_idp_hint={idp_hint}&pkce=y",
    "/simplesamlphp/module.php/core/loginuserpass.php-1",
    "/simplesamlphp/module.php/core/loginuserpass.php-2",
    "/auth/realms/ID-Broker/broker/{traeger}/endpoint",
    "/ucsschool/apis/self_disclosure/v1/users/{id}/metadata",
    "/ucsschool/apis/self_disclosure/v1/users/{id}/groups",
    "/ucsschool/apis/self_disclosure/v1/groups/{id}/users",
]


@pytest.fixture(scope="module")
def run_test(execute_test, host_from_env, verify_test_sent_requests):
    os.environ["LOCUST_SPAWN_RATE"] = "0.5"
    os.environ["LOCUST_RUN_TIME"] = "10m"
    os.environ["LOCUST_USERS"] = "300"  # min spawn-rate * runtime in seconds
    execute_test(LOCUST_FILE_PATH, RESULT_FILE_BASE_PATH, host_from_env(HOST))
    # fail in fixture, so pytest prints the output of Locust, regardless which test_*() function started Locust
    verify_test_sent_requests(RESULT_FILE_BASE_PATH)


def test_failure_count(check_failure_count, run_test):
    check_failure_count(RESULT_FILE_BASE_PATH)


def test_rps(check_rps, run_test):
    for url in URL_NAMES:
        check_rps(RESULT_FILE_BASE_PATH, url, 0.1)  # TODO: set desired target performance


def test_95_percentile(check_95_percentile, run_test):
    for url_name in URL_NAMES:
        check_95_percentile(
            RESULT_FILE_BASE_PATH, url_name, 10000
        )  # TODO: set desired target performance

==> id-broker-plugin_2.3.0.tar.gz: id-broker-plugin-2.3.0/tests/host/98_ucsschool-id-broker-performance/36_selfd_teacher_flow.py <==
#!/usr/share/ucs-test/runner /usr/bin/pytest-3 -l -v
## -*- coding: utf-8 -*-
## desc: check performance of teacher flow (get token - get metadata - get groups - get users of groups)
## tags: [ucsschool-id-broker, self-disclosure-api, performance]
## exposure: safe
## packages: []
## bugs: [54547]

import os

import pytest

LOCUST_PARALLEL = os.environ.get("LOCUST_PARALLEL", None)

BASE_DIR = "/var/lib/id-broker-performance-tests"
RESULT_DIR = os.path.join(BASE_DIR, "results")
LOCUST_FILES_DIR = os.path.join(BASE_DIR, "performance_tests", "self_disclosure")

LOCUST_FILE = "teacher_flow.py"
LOCUST_FILE_PATH = os.path.join(LOCUST_FILES_DIR, LOCUST_FILE)
if LOCUST_PARALLEL:
    RESULT_FILE_BASE_PATH = os.path.join(
        RESULT_DIR, "parallel_self-disclosure_teacher_flow"
    )
else:
    RESULT_FILE_BASE_PATH = os.path.join(RESULT_DIR, "self-disclosure_teacher_flow")
HOST = "self-disclosure"
URL_NAMES = [
    "login?kc_idp_hint={idp_hint}&pkce=y",
    "/simplesamlphp/module.php/core/loginuserpass.php-1",
    "/simplesamlphp/module.php/core/loginuserpass.php-2",
    "/auth/realms/ID-Broker/broker/{traeger}/endpoint",
    "/ucsschool/apis/self_disclosure/v1/users/{id}/metadata",
    "/ucsschool/apis/self_disclosure/v1/users/{id}/groups",
    "/ucsschool/apis/self_disclosure/v1/groups/{id}/users",
]


@pytest.fixture(scope="module")
def run_test(execute_test, host_from_env, verify_test_sent_requests):
    os.environ["LOCUST_SPAWN_RATE"] = "0.5"
    os.environ["LOCUST_RUN_TIME"] = "10m"
    os.environ["LOCUST_USERS"] = "300"  # min spawn-rate * runtime in seconds
    execute_test(LOCUST_FILE_PATH, RESULT_FILE_BASE_PATH, host_from_env(HOST))
    # fail in fixture, so pytest prints the output of Locust, regardless which test_*() function started Locust
    verify_test_sent_requests(RESULT_FILE_BASE_PATH)


def test_failure_count(check_failure_count, run_test):
    check_failure_count(RESULT_FILE_BASE_PATH)


def test_rps(check_rps, run_test):
    for url in URL_NAMES:
        check_rps(
            RESULT_FILE_BASE_PATH, url, 0.1
        )  # TODO: set desired target performance


def test_95_percentile(check_95_percentile, run_test):
    for url_name in URL_NAMES:
        check_95_percentile(
            RESULT_FILE_BASE_PATH, url_name, 10000
        )  # TODO: set desired target performance
